==> owncloud-app-contacts-2%3A1.2.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/fi_FI.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Yhteystiedot",
    "Address book name" : "Osoitekirjan nimi",
    "No contacts in here" : "Ei yhteytietoja",
    "Name" : "Nimi",
    "Organization" : "Organisaatio",
    "Title" : "Otsikko",
    "Add field ..." : "Lisää kenttä...",
    "Import" : "Tuo",
    "Add contact" : "Lisää yhteystieto",
    "No search result for {query}" : "Ei tuloksia haulle {query}",
    "All contacts" : "Kaikki yhteystiedot",
    "Not grouped" : "Ei ryhmitelty",
    "Post Office Box" : "Postilokero",
    "Postal Code" : "Postinumero",
    "City" : "Paikkakunta",
    "State or province" : "Maakunta tai osavaltio",
    "Country" : "Maa",
    "Address" : "Osoite",
    "(new group)" : "(uusi ryhmä)",
    "New contact" : "Uusi yhteystieto",
    "{addressbook} shared by {owner}" : "Osoitekirjan {addressbook} jakoi {owner}",
    "Invalid file type." : "Virheellinen tiedostotyyppi.",
    "Nickname" : "Kutsumanimi",
    "Notes" : "Huomiot",
    "Website" : "Verkkosivusto",
    "Federated Cloud ID" : "Federoidun pilven tunniste",
    "Home" : "Koti",
    "Work" : "Työ",
    "Other" : "Muu",
    "Groups" : "Ryhmät",
    "Birthday" : "Syntymäpäivä",
    "Email" : "Sähköpostiosoite",
    "Instant messaging" : "Pikaviestintä",
    "Phone" : "Puhelin",
    "Mobile" : "Mobiili",
    "Fax" : "Faksi",
    "Fax home" : "Faksi, koti",
    "Fax work" : "Faksi, työ",
    "Pager" : "Hakulaite",
    "Voice" : "Ääni",
    "Social Network" : "Sosiaalinen verkko",
    "Settings" : "Asetukset"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.3.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/fi_FI.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Yhteystiedot",
    "Address book name" : "Osoitekirjan nimi",
    "No contacts in here" : "Ei yhteytietoja",
    "Name" : "Nimi",
    "Organization" : "Organisaatio",
    "Title" : "Otsikko",
    "Add field ..." : "Lisää kenttä...",
    "Import" : "Tuo",
    "Add contact" : "Lisää yhteystieto",
    "No search result for {query}" : "Ei tuloksia haulle {query}",
    "All contacts" : "Kaikki yhteystiedot",
    "Not grouped" : "Ei ryhmitelty",
    "Post Office Box" : "Postilokero",
    "Postal Code" : "Postinumero",
    "City" : "Paikkakunta",
    "State or province" : "Maakunta tai osavaltio",
    "Country" : "Maa",
    "Address" : "Osoite",
    "(new group)" : "(uusi ryhmä)",
    "New contact" : "Uusi yhteystieto",
    "{addressbook} shared by {owner}" : "Osoitekirjan {addressbook} jakoi {owner}",
    "No contacts in file. Only VCard files are allowed." : "Ei yhteystietoja tiedostossa. Vain vCard-tiedostot ovat sallittuja.",
    "Nickname" : "Kutsumanimi",
    "Notes" : "Huomiot",
    "Website" : "Verkkosivusto",
    "Federated Cloud ID" : "Federoidun pilven tunniste",
    "Home" : "Koti",
    "Work" : "Työ",
    "Other" : "Muu",
    "Groups" : "Ryhmät",
    "Birthday" : "Syntymäpäivä",
    "Email" : "Sähköpostiosoite",
    "Instant messaging" : "Pikaviestintä",
    "Phone" : "Puhelin",
    "Mobile" : "Mobiili",
    "Fax" : "Faksi",
    "Fax home" : "Faksi, koti",
    "Fax work" : "Faksi, työ",
    "Pager" : "Hakulaite",
    "Voice" : "Ääni",
    "Social Network" : "Sosiaalinen verkko",
    "Settings" : "Asetukset"
},
"nplurals=2; plural=(n != 1);");
